{
    ss_main.pas
    
	This file is a part of
	
    EasySlideShowMaker v. 1.41  -  A easy GNU slide show maker.
    Copyright (C) 2010  Patrick Eigensatz

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY;
   
    without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU General Public License (added as "License.txt") for
    more information.
}

unit ss_main;

{$mode objfpc}{$H+}

interface

uses
  Classes, SysUtils, FileUtil, LResources, Forms, Controls, Graphics, Dialogs,
  StdCtrls, ExtCtrls;

type

  { TSlideShowForm }

  TSlideShowForm = class(TForm)
    Image1: TImage;
    Label1: TLabel;
    Label2: TLabel;
    procedure FormClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure FormKeyUp(Sender: TObject; var Key: Word; Shift: TShiftState);
    procedure FormMouseWheelDown(Sender: TObject; Shift: TShiftState;
      MousePos: TPoint; var Handled: Boolean);
    procedure FormMouseWheelUp(Sender: TObject; Shift: TShiftState;
      MousePos: TPoint; var Handled: Boolean);
    procedure Image1Click(Sender: TObject);
    procedure Image1MouseWheelDown(Sender: TObject; Shift: TShiftState;
      MousePos: TPoint; var Handled: Boolean);
    procedure Image1MouseWheelUp(Sender: TObject; Shift: TShiftState;
      MousePos: TPoint; var Handled: Boolean);
  private
    { private declarations }
  public
    { public declarations }
  end; 

var
  SlideShowForm: TSlideShowForm;
  img, maximg : Integer;
  x : Integer;
  ext, exepath : String;
  fs : Boolean;
  config, Exten, Captions : TStringlist;

implementation

{ TSlideShowForm }

procedure ShowImage;
begin
try
SlideShowForm.Label1.Caption := Captions.Strings[img];
ext := Exten.Strings[img];
SlideShowForm.Image1.Picture.LoadFromFile(IntToStr(img) + '.' + ext);

slideShowForm.Label2.Caption := IntToStr(img+1) + '/' + IntToStr(maximg);

{* If Label bigger than the picture, !respect the label!
   Else: !respect the picture!
   In such way, the xform can itself extend so that the picture and the label in the form have place.
   The form becomes still some pixels more, than the picture (and/or the label).
  *}

If not fs then  // Just adjust the window, if not fullscreen mode selected!
begin

SlideShowForm.Position := poScreenCenter;

If SlideShowForm.Label1.Width > SlideShowForm.Image1.Picture.Width then
begin
x := SlideShowForm.Label1.Width - SlideShowForm.Width;
SlideShowForm.Width := SlideShowForm.Image1.Picture.Width + x + 50;
end;

// else:
If SlideShowForm.Image1.Picture.Width > SlideShowForm.Label1.Width then
begin
x := SlideShowForm.Image1.Picture.Width - SlideShowForm.Label1.Width;
SlideShowForm.Width := SlideShowForm.Label1.Width + x + 50;
end;

SlideShowForm.Height := SlideShowForm.Image1.Picture.Height + 75;

{still 25 pixels more at the
 downside and 50 pixels more
 at the upside!}
end;


except
showmessage('Error by loading picture number: ' + IntToStr(img));
img := 0;
ShowImage;
end;
end;

procedure TSlideShowForm.FormCreate(Sender: TObject);
begin
try

// Create Stringlist!
config := TStringlist.Create;
Captions := TStringlist.Create;
Exten := TStringlist.Create;

exepath := ExtractFilePath(Application.ExeName);  //PATCH:  Get executable path!

config.LoadFromFile(exepath + 'slideshow.ini');
Exten.LoadFromFile(exepath + 'ext.ini');
Captions.LoadFromFile(exepath + 'cap.ini');


If config.Strings[1] = 'fs' then    // Check for fullscreen!
begin
// Set Windowposition!
fs := true;
Slideshowform.Width := Screen.Width;
Slideshowform.Height := Screen.Height;
Slideshowform.Position := poScreencenter;
Application.BringToFront;
end;

Label1.Font.Color := StrToInt(config.Strings[5]);
Label2.Font.Color := StrToInt(config.Strings[5]);

SlideShowForm.Caption := config.Strings[2];
SlideShowForm.Color := StrToInt(config.Strings[3]);
maximg := StrToInt(config.Strings[0]);
ShowImage;

except
 showmessage('Error by loading slideshow!');
 close;
end;

// Show Label2 or hide it?

If config.Strings[4] = 'false' then
  begin
    Label2.Visible := false;
    Label1.Left := 16;  // Show Label1 on the left position of Label2!
  end;                  // Else:  All settings are like designed!

end;

procedure TSlideShowForm.FormKeyUp(Sender: TObject; var Key: Word;
  Shift: TShiftState);
begin
    If key = 32 then    // Spacebar
    begin
      img := img + 1;
      If img = maximg then img := 0;
      ShowImage;
    end;

  If key = 39 then      // Arrow Right
    begin
      img := img + 1;
      If img = maximg then img := 0;
      ShowImage;
    end;

  If key = 37 then      // Arrow Left
    begin
      img := img - 1;
      If img = -1 then img := maximg-1;
      ShowImage;
    end;
end;

procedure TSlideShowForm.FormClick(Sender: TObject);
begin
  img := img + 1;
  If img = maximg then img := 0;
  ShowImage;
end;

procedure TSlideShowForm.FormMouseWheelDown(Sender: TObject;
  Shift: TShiftState; MousePos: TPoint; var Handled: Boolean);
begin
  img := img - 1;
  If img = -1 then img := maximg-1;
  ShowImage;
end;

procedure TSlideShowForm.FormMouseWheelUp(Sender: TObject; Shift: TShiftState;
  MousePos: TPoint; var Handled: Boolean);
begin
  img := img + 1;
  If img = maximg then img := 0;
  ShowImage;
end;

procedure TSlideShowForm.Image1Click(Sender: TObject);
begin
  img := img + 1;
  If img = maximg then img := 0;
  ShowImage;
end;

procedure TSlideShowForm.Image1MouseWheelDown(Sender: TObject;
  Shift: TShiftState; MousePos: TPoint; var Handled: Boolean);
begin
  img := img - 1;
  If img = -1 then img := maximg-1;
  ShowImage;
end;

procedure TSlideShowForm.Image1MouseWheelUp(Sender: TObject;
  Shift: TShiftState; MousePos: TPoint; var Handled: Boolean);
begin
  img := img + 1;
  If img = maximg then img := 0;
  ShowImage;
end;


initialization
  {$I ss_main.lrs}

end.

